@@ -19,4 +19,4 @@ class TestAll:
         with patch('requests.get') as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
-            c = Client()
+            c = Client(version='sandbox')
